@@ -7,7 +7,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-07-24'; # DATE
 our $DIST = 'Sah-Schemas-Unix'; # DIST
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 
 sub meta {
     +{
@@ -26,7 +26,7 @@ sub filter {
 
     $res->{expr_filter} = join(
         "",
-        "do { my \$tmp = $dt; if (\$tmp !~ /\\A[0-9]+\\z/) { my \@gr = getgrnam(\$tmp); \@gr ? [undef, \$gr[2]] : [\"Unknown Unix user '\$tmp'\", \$tmp] } else { [undef, \$tmp] } }",
+        "do { my \$tmp = $dt; if (\$tmp !~ /\\A[0-9]+\\z/) { my \@gr = getgrnam(\$tmp); \@gr ? [undef, \$gr[2]] : [\"Unknown Unix group '\$tmp'\", \$tmp] } else { [undef, \$tmp] } }",
     );
 
     $res;
@@ -47,7 +47,7 @@ Data::Sah::Filter::perl::Unix::convert_unix_group_to_gid
 
 =head1 VERSION
 
-This document describes version 0.019 of Data::Sah::Filter::perl::Unix::convert_unix_group_to_gid (from Perl distribution Sah-Schemas-Unix), released on 2022-07-24.
+This document describes version 0.020 of Data::Sah::Filter::perl::Unix::convert_unix_group_to_gid (from Perl distribution Sah-Schemas-Unix), released on 2022-07-24.
 
 =for Pod::Coverage ^(meta|filter)$
 
